summaryrefslogtreecommitdiffstats
path: root/kandy/src/cmdpropertiesdialog.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kandy/src/cmdpropertiesdialog.cpp')
-rw-r--r--kandy/src/cmdpropertiesdialog.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/kandy/src/cmdpropertiesdialog.cpp b/kandy/src/cmdpropertiesdialog.cpp
index b71a62f2..3e72754f 100644
--- a/kandy/src/cmdpropertiesdialog.cpp
+++ b/kandy/src/cmdpropertiesdialog.cpp
@@ -36,8 +36,8 @@
class ParameterItem : public TQCheckListItem {
public:
- ParameterItem(ATParameter *p,TQListView *tqparent) :
- TQCheckListItem(tqparent,p->name(),CheckBox),mParameter(p)
+ ParameterItem(ATParameter *p,TQListView *parent) :
+ TQCheckListItem(parent,p->name(),CheckBox),mParameter(p)
{
setText(1,p->value());
setOn(p->userInput());
@@ -56,16 +56,16 @@ class ParameterItem : public TQCheckListItem {
/*
* Constructs a CmdPropertiesDialog which is a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'
*
* The dialog will by default be modeless, unless you set 'modal' to
* TRUE to construct a modal dialog.
*/
-CmdPropertiesDialog::CmdPropertiesDialog(ATCommand *cmd, TQWidget* tqparent,
+CmdPropertiesDialog::CmdPropertiesDialog(ATCommand *cmd, TQWidget* parent,
const char* name, bool modal,
WFlags fl )
- : CmdPropertiesDialog_base( tqparent, name, modal, fl )
+ : CmdPropertiesDialog_base( parent, name, modal, fl )
{
mCmd = cmd;
@@ -56,16 +56,16 @@ class ParameterItem : public TQCheckListItem {
/*
- * Constructs a CmdPropertiesDialog which is a child of 'tqparent', with the
+ * Constructs a CmdPropertiesDialog which is a child of 'parent', with the
* name 'name' and widget flags set to 'f'
*